searchData={"items":[{"type":"module","title":"bugsnag","doc":"BugSnag Erlang client.","ref":"bugsnag.html"},{"type":"module","title":"Configuration - bugsnag","doc":"It can be configured using application environment variables or by passing a map to the\n`start_link/1` function.\n\nIf using application environment variables, the config looks like the following:\n```erlang\n{bugsnag_erlang, [\n    {enabled, true},\n    {api_key, \"BUGSNAG_API_KEY\"},\n    {release_stage, \"production\"},\n    {handler_name, bugsnag_logger_handler},\n    {pool_size, 10}\n]}\n```\nIf `enabled` is set to other than true, the rest of the configuration won't be read\nand no handler will be registered. For the rest of the keys, see `t:config/0`.\n\nIf a new handler wants to be added, the `handler_name` key can be set to a new atom.","ref":"bugsnag.html#module-configuration"},{"type":"function","title":"bugsnag.add_handler/1","doc":"Add a new logger handler.","ref":"bugsnag.html#add_handler/1"},{"type":"function","title":"bugsnag.add_handler/2","doc":"Add a new logger handler.","ref":"bugsnag.html#add_handler/2"},{"type":"function","title":"bugsnag.notify/3","doc":"Notify of a bugsnag event.\n\n1. Events that contain `#{class := _, reason := _, stacktrace := _}`, following the naming\n    convention as exemplified by `erlang:raise/3`, will be treated as exceptions to BugSnag.\n2. Event structure will have all their printable key-value pairs as key-value pairs in `metaData`","ref":"bugsnag.html#notify/3"},{"type":"function","title":"bugsnag.notify/5","doc":"Notify a global worker about an exception.","ref":"bugsnag.html#notify/5"},{"type":"function","title":"bugsnag.notify/7","doc":"Notify a global worker about an exception.","ref":"bugsnag.html#notify/7"},{"type":"function","title":"bugsnag.remove_handler/1","doc":"Remove a new logger handler.","ref":"bugsnag.html#remove_handler/1"},{"type":"function","title":"bugsnag.start_link/2","doc":"Add a new global `bugsnag_logger_handler` handler.\n\nThis is deprecated, `add_handler/1` is preferred.","ref":"bugsnag.html#start_link/2"},{"type":"type","title":"bugsnag.config/0","doc":"Configuration options for the Bugsnag client.\n\nIt takes the following configuration options:\n\n- `api_key`: the Bugsnag API key, mandatory to provide.\n- `release_stage`: the release stage of the application, defaults to `production`\n- `name`: defaults to `bugsnag_logger_handler`, but allows to create more `logger` handlers\n    with different configurations.\n- `pool_size`: defaults to the number of schedulers, increases the number of workers in the pool\n    in case of high load.\n- `endpoint`: allows you to configure a custom config, including testing endpoints.\n- `events_limit`: allows you to configure the maximum number of events to be sent to Bugsnag at\n    once. If event queues fill too fast, older non-sent events will be dropped.\n    The default is 1000, as an average big event including stacktraces is no bigger than 1KB,\n    therefore 1000 events should keep the payload below 1MB.","ref":"bugsnag.html#t:config/0"},{"type":"type","title":"bugsnag.event/0","doc":"Event to notify to BugSnag.\n\n1. Events that contain `#{class := _, reason := _, stacktrace := _}`, following the naming\n    convention as exemplified by `erlang:raise/3`, will be treated as exceptions to BugSnag.\n2. Event structure will have all their printable key-value pairs as key-value pairs in `metaData`.\n3. `breadcrumbs` will always contain the timestamp of the event.","ref":"bugsnag.html#t:event/0"},{"type":"type","title":"bugsnag.metadata/0","doc":"Metadata about the event.\n\nThe default severity level is `warning`.\nThe default `mfa` is `{undefined, undefined, 0}` and `line` is also 0.","ref":"bugsnag.html#t:metadata/0"},{"type":"type","title":"bugsnag.text/0","doc":"A printable string","ref":"bugsnag.html#t:text/0"},{"type":"module","title":"bugsnag_error_logger","doc":"An `m:error_logger` handler to report messages above a certain level to BugSnag","ref":"bugsnag_error_logger.html"},{"type":"module","title":"bugsnag_lager_handler","doc":"A `m:lager` handler to report messages above a certain level to BugSnag","ref":"bugsnag_lager_handler.html"},{"type":"opaque","title":"bugsnag_lager_handler.state/0","doc":"State of the lager handler `gen_event` worker","ref":"bugsnag_lager_handler.html#t:state/0"},{"type":"module","title":"bugsnag_logger_handler","doc":"Logger handler module for BugSnag.\n\nIt is specially tailored to structured logging, and therefore unstructured logging will be treated\nstructurised ad-hoc, with the message being the only field of the `t:bugsnag:event/0`.\nEvents that contain a `t:logger:report_cb()` will have this printable string as its `message`.","ref":"bugsnag_logger_handler.html"},{"type":"function","title":"bugsnag_logger_handler.log/2","doc":"OTP logger-compliant handler for BugSnag","ref":"bugsnag_logger_handler.html#log/2"},{"type":"extras","title":"Overview","doc":"# Insight Hub (Bugsnag) notifier for Erlang\n\n[![Build Status](https://github.com/dnsimple/bugsnag-erlang/actions/workflows/ci.yml/badge.svg)](https://github.com/dnsimple/bugsnag-erlang/actions/workflows/ci.yml)\n[![Module Version](https://img.shields.io/hexpm/v/bugsnag_erlang.svg)](https://hex.pm/packages/bugsnag_erlang)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/bugsnag_erlang/)\n[![Hex Downloads](https://img.shields.io/hexpm/dt/bugsnag_erlang.svg?maxAge=2592000)](https://hex.pm/packages/bugsnag_erlang)\n[![Coverage Status](https://coveralls.io/repos/github/dnsimple/bugsnag-erlang/badge.svg?branch=main)](https://coveralls.io/github/dnsimple/bugsnag-erlang?branch=main)","ref":"readme.html"},{"type":"extras","title":"Usage - Overview","doc":"You may send custom errors directly\n\n```erlang\nbugsnag:notify(error, fake, \"Testing bugsnag with a manual error report\", no_module, 0).\n```\n\nOr use the Erlang error logger\n\n```erlang\nerror_logger:error_msg(\"A sample error caught by the bugsnag error logger.\").\n```\n\nOr `logger`:\n\n```erlang\n?LOG_ERROR(#{what => example_error, text => \"A sample error caught by the bugsnag logger handler\"}).\n```\n\nWhen embedding, make sure to set up the configuration elements in your `sys.config` (or other config file),\nSee `m:bugsnag` for configuration details.","ref":"readme.html#usage"},{"type":"extras","title":"Lager handler - Overview","doc":"We also provide a [lager](https://github.com/basho/lager) handler to report anything\nabove a certain level (by default, `error`) to Bugsnag.\n\nFor example, simply add to your `sys.config`\n\n```erlang\n{bugsnag_lager_handler, critical}\n```\n\nto your lager handler config.","ref":"readme.html#lager-handler"},{"type":"extras","title":"Testing - Overview","doc":"To test the codebase:\n\n```shell\nmake test\n```","ref":"readme.html#testing"},{"type":"extras","title":"Formatting - Overview","doc":"To format the codebase\n\n```shell\nmake format\n```","ref":"readme.html#formatting"},{"type":"extras","title":"Thanks - Overview","doc":"Thank you to Ken Pratt: his library   provided a lot of code for this library.","ref":"readme.html#thanks"},{"type":"extras","title":"License","doc":"Copyright (c) 2013-2019 Anthony Eden\nCopyright (c) 2020-2025 DNSimple Corporation\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the \"Software\"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"proglang":"erlang","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}